/*
 * PHP => moment.js
 * Will take a php date format and convert it into a JS format for moment
 * http://www.php.net/manual/en/function.date.php
 * http://momentjs.com/docs/#/displaying/format/
 * 
 * Usage Example
 * You can pass whatever date into the moment call and any php date format into the formatter.
 * moment(new Date()).formatPHP("examplePHPFormat");
 * 
 * taken from: https://gist.github.com/phpmypython/f97c5f5f59f2a934599d
 * 
 */


/* Notes: 

moment.js formats:

# Year, month, and day tokens
	
	Input	Example	Description
	YYYY	2014	4 or 2 digit year
	YY	14	2 digit year
	Y	-25	Year with any number of digits and sign
	Q	1..4	Quarter of year. Sets month to first month in quarter.
	M MM	1..12	Month number
	MMM MMMM	Jan..December	Month name in locale set by moment.locale()
	D DD	1..31	Day of month
	Do	1st..31st	Day of month with ordinal
	DDD DDDD	1..365	Day of year
	X	1410715640.579	Unix timestamp
	x	1410715640579	Unix ms timestamp
	YYYY from version 2.10.5 supports 2 digit years, and converts them to a year near 2000 (same as YY).

	Y was added in 2.11.1. It will match any number, signed or unsigned. 
	It is useful for years that are not 4 digits or are before the common era. It can be used for any year.


# Week year, week, and weekday tokens
	
	For these, the lowercase tokens use the locale aware week start days, and the uppercase tokens use the ISO week date start days.
	
	Input	Example	Description
	gggg	2014	Locale 4 digit week year
	gg	14	Locale 2 digit week year
	w ww	1..53	Locale week of year
	e	1..7	Locale day of week
	ddd dddd	Mon...Sunday	Day name in locale set by moment.locale()
	GGGG	2014	ISO 4 digit week year
	GG	14	ISO 2 digit week year
	W WW	1..53	ISO week of year
	E	1..7	ISO day of week

# Hour, minute, second, millisecond, and offset tokens
	
	Input	Example	Description
	H HH	0..23	24 hour time
	h hh	1..12	12 hour time used with a A.
	a A	am pm	Post or ante meridiem (Note the one character a p are also considered valid)
	m mm	0..59	Minutes
	s ss	0..59	Seconds
	S SS SSS	0..999	Fractional seconds
	Z ZZ	+12:00	Offset from UTC as +-HH:mm, +-HHmm, or Z



# PHP formats... used in the tecArt CRM

	D, j. M Y
	d.m.Y
	d.m.y
	d.m.Y
	d.m.y
	H:i
	H:i:s
	h:i:s a
	h:i:s A
	l, F j, Y
	l, j F
	l, j F Y
	l, j. F
	l, j. F Y
	l, j. M Y
	m/d/Y
	Y-m-d
	y-m-d

*/



(function (m) {
	var formatMap = {
			d: 'DD',
			D: 'ddd',
			j: 'D',
			l: 'dddd',
			N: 'E',
			S: function () {
				return '[' + this.format('Do').replace(/\d*/g, '') + ']';
			},
			w: 'd',
			z: function () {
				return this.format('DDD') - 1;
			},
			W: 'W',
			F: 'MMMM',
			m: 'MM',
			M: 'MMM',
			n: 'M',
			t: function () {
				return this.daysInMonth();
			},
			L: function () {
				return this.isLeapYear() ? 1 : 0;
			},
			o: 'GGGG',
			Y: 'YYYY',
			y: 'YY',
			a: 'a',
			A: 'A',
			B: function () {
				var thisUTC = this.clone().utc(),
				// Shamelessly stolen from http://javascript.about.com/library/blswatch.htm
					swatch = ((thisUTC.hours() + 1) % 24) + (thisUTC.minutes() / 60) + (thisUTC.seconds() / 3600);
				return Math.floor(swatch * 1000 / 24);
			},
			g: 'h',
			G: 'H',
			h: 'hh',
			H: 'HH',
			i: 'mm',
			s: 'ss',
			u: '[u]', // not sure if moment has this
			e: '[e]', // moment does not have this
			I: function () {
				return this.isDST() ? 1 : 0;
			},
			O: 'ZZ',
			P: 'Z',
			T: '[T]', // deprecated in moment
			Z: function () {
				return parseInt(this.format('ZZ'), 10) * 36;
			},
			c: 'YYYY-MM-DD[T]HH:mm:ssZ',
			r: 'ddd, DD MMM YYYY HH:mm:ss ZZ',
			U: 'X'
		},
		formatEx = /[dDjlNSwzWFmMntLoYyaABgGhHisueIOPTZcrU]/g;

	moment.fn.formatPHP = function (format) {
		var that = this;

		return this.format(format.replace(formatEx, function (phpStr) {
			return typeof formatMap[phpStr] === 'function' ? formatMap[phpStr].call(that) : formatMap[phpStr];
		}));
	};

	moment.fn.get_format_php = function(_format)
	{
		var that = this;

		var format = '';

		for (var index = 0; index < _format.length; ++ index)
		{
			var iks = typeof typeof formatMap[_format[index]] === 'function' ? formatMap[_format[index]].call(that) : formatMap[_format[index]];
			format += (iks !== undefined ? iks : _format[index]);
		}

		return format;
	};

}(moment));